@@ -7,14 +7,8 @@ from py42.sdk.queries.query_filter import FilterGroup
 
 from code42cli.click_ext.options import incompatible_with
 from code42cli.click_ext.types import FileOrString
-from code42cli.date_helper import parse_max_timestamp
-from code42cli.date_helper import parse_min_timestamp
-from code42cli.logger import get_main_cli_logger
-from code42cli.options import begin_option
-from code42cli.options import end_option
-
-
-logger = get_main_cli_logger()
+from code42cli.logger.enums import ServerProtocol
+from code42cli.output_formats import SendToFileEventsOutputFormat
 
 
 def is_in_filter(filter_cls):
@@ -101,9 +95,8 @@ class BeginOption(AdvancedQueryAndSavedSearchIncompatible):
                     checkpoint_value, timezone.utc
                 ).isoformat()
                 click.echo(
-                    "Ignoring --begin value as --use-checkpoint was passed and checkpoint of {} exists.\n".format(
-                        checkpoint_value_str
-                    ),
+                    "Ignoring --begin value as --use-checkpoint was passed and checkpoint of "
+                    f"{checkpoint_value_str} exists.\n",
                     err=True,
                 )
             if (
@@ -128,56 +121,60 @@ def _parse_query_from_json(ctx, param, arg):
         filter_groups = [FilterGroup.from_dict(group) for group in query["groups"]]
         return filter_groups
     except json.JSONDecodeError as json_error:
-        raise click.BadParameter("Unable to parse JSON: {}".format(json_error))
+        raise click.BadParameter(f"Unable to parse JSON: {json_error}")
     except KeyError as key_error:
-        raise click.BadParameter(
-            "Unable to build query from input JSON: {}".format(key_error)
-        )
+        raise click.BadParameter(f"Unable to build query from input JSON: {key_error}")
 
 
-def search_interval_options(f, search_term):
-    f = begin_option(
-        f,
-        search_term,
-        cls=BeginOption,
-        callback=lambda ctx, param, arg: parse_min_timestamp(arg),
-    )
-    f = end_option(
-        f,
-        search_term,
-        cls=AdvancedQueryAndSavedSearchIncompatible,
-        callback=lambda ctx, param, arg: parse_max_timestamp(arg),
-    )
-    return f
-
-
-def create_search_options(search_term):
-
-    advanced_query_option = click.option(
-        "--advanced-query",
-        help="A raw JSON {} query. "
+def advanced_query_option(term, **kwargs):
+    defaults = dict(
+        help=f"A raw JSON {term} query. "
         "Useful for when the provided query parameters do not satisfy your requirements. "
         "Argument can be passed as a string, read from stdin by passing '-', or from a filename if "
         "prefixed with '@', e.g. '--advanced-query @query.json'. "
-        "WARNING: Using advanced queries is incompatible with other query-building arguments.".format(
-            search_term
-        ),
+        "WARNING: Using advanced queries is incompatible with other query-building arguments.",
         metavar="QUERY_JSON",
         type=FileOrString(),
         callback=_parse_query_from_json,
     )
-    checkpoint_option = click.option(
-        "-c",
-        "--use-checkpoint",
-        help="Only get {} that were not previously retrieved.".format(search_term),
-        cls=incompatible_with("saved_search"),
+    defaults.update(kwargs)
+    return click.option("--advanced-query", **defaults)
+
+
+def server_options(f):
+    hostname_arg = click.argument("hostname")
+    protocol_option = click.option(
+        "-p",
+        "--protocol",
+        type=click.Choice(ServerProtocol(), case_sensitive=False),
+        default=ServerProtocol.UDP,
+        help="Protocol used to send logs to server. "
+        "Use TCP-TLS for additional security. Defaults to UDP.",
     )
+    certs_option = click.option(
+        "--certs",
+        type=str,
+        help="A CA certificates-chain file for the TCP-TLS protocol.",
+    )
+    ignore_cert_validation = click.option(
+        "--ignore-cert-validation",
+        help="Set to skip CA certificate validation. "
+        "Incompatible with the 'certs' option.",
+        is_flag=True,
+        default=None,
+        cls=incompatible_with(["certs"]),
+    )
+    f = hostname_arg(f)
+    f = protocol_option(f)
+    f = certs_option(f)
+    f = ignore_cert_validation(f)
+    return f
 
-    def search_options(f):
 
-        f = search_interval_options(f, search_term)
-        f = checkpoint_option(f)
-        f = advanced_query_option(f)
-        return f
-
-    return search_options
+send_to_format_options = click.option(
+    "-f",
+    "--format",
+    type=click.Choice(SendToFileEventsOutputFormat(), case_sensitive=False),
+    help="The output format of the result. Defaults to RAW-JSON format.",
+    default=SendToFileEventsOutputFormat.RAW,
+)
